Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutMenuList.h

Issue 2086663007: Use fixed logical height in LayoutMenuList (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutMenuList.h
diff --git a/third_party/WebKit/Source/core/layout/LayoutMenuList.h b/third_party/WebKit/Source/core/layout/LayoutMenuList.h
index de2299b79358b6c68d929527fdda2fb90b6e2110..51c643dc9889a31eedb7c90d86c0637f73b90056 100644
--- a/third_party/WebKit/Source/core/layout/LayoutMenuList.h
+++ b/third_party/WebKit/Source/core/layout/LayoutMenuList.h
@@ -80,8 +80,7 @@ private:
void adjustInnerStyle();
void setText(const String&);
void setTextFromOption(int optionIndex);
- void updateOptionsHeightWidth() const;
- float computeTextHeight(const TextRun&, const ComputedStyle&) const;
+ void updateOptionsWidth() const;
float computeTextWidth(const TextRun&, const ComputedStyle&) const;
void setIndexToSelectOnCancel(int listIndex);
@@ -92,9 +91,9 @@ private:
bool m_isEmpty : 1;
bool m_hasUpdatedActiveOption : 1;
- // m_optionsHeight and m_optionsWidth are calculated and cached on demand.
- // updateOptionsHeightWidth() should be called before reading them.
- mutable int m_optionsHeight;
+ LayoutUnit m_innerBlockHeight;
+ // m_optionsWidth is calculated and cached on demand.
+ // updateOptionsWidth() should be called before reading them.
mutable int m_optionsWidth;
int m_lastActiveIndex;

Powered by Google App Engine
This is Rietveld 408576698